@@ -18,12 +18,13 @@ setClass("SQLiteResult",
   slots = list(
     sql = "character",
     ptr = "externalptr",
-    conn = "SQLiteConnection"
+    conn = "SQLiteConnection",
+    bigint = "character"
   )
 )
 
 #' @rdname SQLiteResult-class
 #' @export
 setMethod("dbIsValid", "SQLiteResult", function(dbObj, ...) {
-  rsqlite_result_valid(dbObj@ptr)
+  result_valid(dbObj@ptr)
 })
