@@ -24,11 +24,11 @@
 initRegExp <- function(db) {
   if (!db@loadable.extensions) {
     stop("Loadable extensions are not enabled for this db connection",
-         call. = FALSE)
+      call. = FALSE
+    )
   }
 
-  lib_path <- getLoadedDLLs()[["RSQLite"]][["path"]]
-  extension_load(db@ptr, lib_path, "sqlite3_regexp_init")
+  extension_load(db@ptr, get_lib_path(), "sqlite3_regexp_init")
 
   # always return TRUE after loading
   invisible(TRUE)
